import typing

GenericType = typing.TypeVar("GenericType")

def add_scrollback(text, text_type): ...
def autocomplete(_context): ...
def banner(context): ...
def execute(context, _is_interactive): ...
def shell_run(text): ...
