import typing

GenericType = typing.TypeVar("GenericType")

def indent(levels): ...
def keyconfig_export_as_data(wm, kc, filepath, all_keymaps): ...
def keyconfig_import_from_data(name, keyconfig_data, keyconfig_version): ...
def keyconfig_init_from_data(kc, keyconfig_data): ...
def keyconfig_merge(kc1, kc2): ...
def keymap_init_from_data(km, km_items, is_modal): ...
def kmi_args_as_data(kmi): ...
def repr_f32(f): ...
def round_float_32(f): ...
